@@ -22,13 +22,14 @@
 """Modifies strings to all use the same quote where possible."""
 
 from __future__ import print_function
+from __future__ import unicode_literals
 
 import io
 import os
 import tokenize
 
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 
 try:
@@ -155,7 +156,7 @@ def format_file(filename, args, standard_out):
                 'before/' + filename,
                 'after/' + filename,
                 lineterm='')
-            standard_out.write(unicode('\n').join(list(diff) + ['']))
+            standard_out.write('\n'.join(list(diff) + ['']))
 
 
 def main(argv, standard_out, standard_error):
